================
project-template
================

Overview
--------

"project-template" is a Python template project designed to simplify the setup of a new project.

It provides a basic directory layout, a base set of dependencies, and a set of templates for common files such as
README, LICENSE, setup.py, .gitignore, etc.
